@@ -59,9 +59,10 @@ from .reformatting import Editor
 
 WIDTH = 80
 INITIAL_INDENT = '  * '
+DEFAULT_DISTRIBUTION = 'unstable'
 
 
-class ChangelogEditor(Editor):
+class ChangelogEditor(Editor[Changelog, str]):
     """Update a changelog file.
 
     This will only write out the changelog file if it has been changed.
@@ -207,7 +208,7 @@ def changes_by_author(
     Returns:
       Iterator over items by author (maintainer, offsets, changes)
     """
-    for (author, linenos, contents) in changes_sections(changes):
+    for (author, _linenos, contents) in changes_sections(changes):
         for change_entries in contents:
             change_linenos, change_lines = zip(*change_entries)
             yield (author, change_linenos, change_lines)  # type: ignore
@@ -306,7 +307,7 @@ def rewrap_changes(changes: Iterator[str]) -> Iterator[str]:
             yield line
 
 
-def _inc_version(version: Version) -> Version:
+def increment_version(version: Version) -> Version:
     """Increment a Debian version string."""
     ret = Version(str(version))
     # TODO(jelmer): Add ubuntuX suffix on Ubuntu
@@ -380,7 +381,7 @@ def changelog_add_entry(
     else:
         cl.new_block(
             package=cl[0].package,
-            version=_inc_version(cl[0].version),
+            version=increment_version(cl[0].version),
             urgency=urgency,
             author="%s <%s>" % (maintainer_name, maintainer_email),
             date=format_datetime(timestamp),
@@ -493,8 +494,14 @@ def distribution_is_unreleased(distribution):
         distribution.startswith('UNRELEASED-'))
 
 
-def changeblock_ensure_first_line(block, line, maintainer=None):
+def changeblock_ensure_first_line(
+        block, line, maintainer: Optional[Tuple[str, str]] = None):
     """Ensure that the first line matches the specified line.
+
+    Args:
+      block: Changelog block to edit
+      line: Line to add
+      maintainer: Maintainer to reference as (name, email)-tuple
     """
     if maintainer is None:
         maintainer_name, maintainer_email = get_maintainer()
@@ -517,10 +524,45 @@ def changeblock_ensure_first_line(block, line, maintainer=None):
         block.author = "%s <%s>" % (maintainer_name, maintainer_email)
 
 
-def release(cl, distribution="unstable", timestamp=None, localtime=True):
+def take_uploadership(
+        block, maintainer: Optional[Tuple[str, str]] = None) -> None:
+    """Take uploaderhsip of a changelog entry, but attribute contributors.
+
+    Args:
+      block: Changelog block to modify
+      maintainer: Tuple with (name, email) of maintainer to take ownership
+    """
+    if maintainer is None:
+        maintainer_name, maintainer_email = get_maintainer()
+    else:
+        maintainer_name, maintainer_email = maintainer
+    if maintainer_name is None or maintainer_email is None:
+        raise ValueError(
+            'unable to determine maintainer details and none specified')
+    if block.author is not None:
+        entry_maintainer = parseaddr(block.author)
+        if (entry_maintainer != (maintainer_name, maintainer_email) and
+                len(block._changes) >= 2 and
+                not block._changes[1].startswith('  [ ')):
+            block._changes.insert(1, '  [ %s ]' % entry_maintainer[0])
+            if block._changes[-1]:
+                block._changes.append('')
+    block.author = '%s <%s>' % (maintainer_name, maintainer_email)
+
+
+def release(
+        cl, distribution: Optional[str] = None, timestamp=None,
+        localtime: bool = True,
+        maintainer: Optional[Tuple[str, str]] = None):
     """Create a release for a changelog file.
     """
+    if distribution is None:
+        try:
+            distribution = cl[1].distributions
+        except IndexError:
+            distribution = DEFAULT_DISTRIBUTION
     if distribution_is_unreleased(cl[0].distributions):
+        take_uploadership(cl[0], maintainer)
         cl[0].distributions = distribution
         cl[0].date = format_date(timestamp=timestamp, localtime=localtime)
 
@@ -545,8 +587,8 @@ def find_extra_authors(changes):
 
     :return: List of fullnames of additional authors, without e-mail address.
     """
-    authors = []
-    for new_author, linenos, lines in changes_by_author(changes):
+    authors: List[str] = []
+    for new_author, _linenos, _lines in changes_by_author(changes):
         if new_author is None:
             continue
         already_included = False
@@ -570,8 +612,8 @@ def find_thanks(changes):
         "((?:\\s+(?:(?:\\w\\.)|(?:\\w+(?:-\\w+)*)))+"
         "(?:\\s+<[^@>]+@[^@>]+>)?)",
         re.UNICODE)
-    thanks = []
-    for new_author, linenos, lines in changes_by_author(changes):
+    thanks: List[str] = []
+    for _new_author, _linenos, lines in changes_by_author(changes):
         for match in thanks_re.finditer(''.join(lines)):
             if thanks is None:
                 thanks = []
@@ -625,10 +667,10 @@ def is_unreleased_inaugural(cl: Changelog) -> bool:
 def gbp_dch(path: str) -> None:
     """Run 'gbp dch'."""
     import os
-    from gbp.scripts.dch import main
+    from gbp.scripts.dch import main as dch_main
     old_cwd = os.getcwd()
     try:
         os.chdir(path)
-        main(['gbp-dch', '--ignore-branch'])
+        dch_main(['gbp-dch', '--ignore-branch'])
     finally:
         os.chdir(old_cwd)
