@@ -46,6 +46,7 @@ from itertools import takewhile
 import operator
 import os
 import re
+import time
 from typing import (
     ContextManager,
     Optional,
@@ -94,6 +95,19 @@ CONTROL_LIST_FIELDS = (
 )
 
 
+class MissingSourceParagraph(Exception):
+    """The first paragraph is not a Source paragraph."""
+
+
+class TemplateExpansionFailed(Exception):
+
+    def __init__(self, command, stderr):
+        self.command = command
+        self.stderr = stderr
+        super(TemplateExpansionFailed, self).__init__(
+            "Template expansion (%r) failed: %s" % (command, stderr))
+
+
 class TemplateExpandCommandMissing(Exception):
 
     def __init__(self, command):
@@ -198,6 +212,8 @@ def guess_template_type(
                         return 'rules'
                     if line.startswith(b'debian/%: debian/%.in'):
                         return 'rules'
+                    if line.startswith(b'include /usr/share/blends-dev/rules'):
+                        return 'rules'
         except FileNotFoundError:
             pass
     try:
@@ -216,10 +232,9 @@ def guess_template_type(
                             template.splitlines(),
                             accept_files_with_error_tokens=True)))
                 except StopIteration:
-                    pass
-                else:
                     build_depends = ''
-                build_depends = deb822.get('Build-Depends', '')
+                else:
+                    build_depends = deb822.get('Build-Depends', '')
                 if any(iter_relations(build_depends, 'gnome-pkg-tools')):
                     return 'gnome'
                 if any(iter_relations(build_depends, 'cdbs')):
@@ -233,7 +248,7 @@ def guess_template_type(
 
 
 def _cdbs_resolve_conflict(
-        para_key: str,
+        para_key: Tuple[str, str],
         field: str,
         actual_old_value: Optional[str],
         template_old_value: Optional[str],
@@ -263,18 +278,22 @@ def _cdbs_resolve_conflict(
 def _expand_control_template(
         template_path: str, path: str, template_type: str):
     package_root = os.path.dirname(os.path.dirname(path)) or '.'
-    if template_type == 'rules':
-        template_mtime = os.stat(template_path).st_mtime
+    if template_type in 'rules':
         try:
             path_mtime = os.stat(path).st_mtime
         except FileNotFoundError:
             path_mtime = None
-        if template_mtime == path_mtime:
-            # Delete path to force it to be regenerated
-            os.unlink(path)
-        subprocess.check_call(
-            ['./debian/rules', 'debian/control'],
-            cwd=package_root)
+        while os.stat(template_path).st_mtime == path_mtime:
+            # Wait until mtime has changed, so that make knows to regenerate.
+            os.utime(template_path, (time.time(), time.time()))
+        try:
+            subprocess.check_call(
+                ['./debian/rules', 'debian/control'],
+                stderr=subprocess.PIPE,
+                cwd=package_root)
+        except subprocess.CalledProcessError as e:
+            raise TemplateExpansionFailed(
+                ["./debian/rules"], e.stderr.decode())
     elif template_type == 'gnome':
         dh_gnome_clean(package_root)
     elif template_type == 'postgresql':
@@ -297,7 +316,7 @@ def _update_control_template(
     with Deb822Editor(
             template_path, accept_files_with_error_tokens=True) as updater:
         resolve_conflict: Optional[Callable[[
-            str, str, Optional[str], Optional[str], Optional[str]],
+            Tuple[str, str], str, Optional[str], Optional[str], Optional[str]],
             Optional[str]]]
         if template_type == 'cdbs':
             resolve_conflict = _cdbs_resolve_conflict
@@ -361,11 +380,16 @@ def _find_template_path(path):
         return None
 
 
+ChangesDict = Dict[
+    Tuple[str, str], List[Tuple[str, Optional[str], Optional[str]]]]
+
+
 class ControlEditor(object):
     """Edit a control file.
     """
 
     changed: bool
+    changed_files: List[str]
     _field_order_preserver: ContextManager
 
     def __init__(self, path: str = 'debian/control',
@@ -398,7 +422,7 @@ class ControlEditor(object):
         """Source package."""
         for entry in self.paragraphs:
             if not entry.get('Source'):
-                raise ValueError('first paragraph is not Source')
+                raise MissingSourceParagraph()
             return entry
         else:
             p = Deb822Paragraph.new_empty_paragraph()
@@ -420,7 +444,7 @@ class ControlEditor(object):
             list of (field_name, old_value, new_value)
         """
         orig = self._primary._parse(self._primary._orig_content)
-        changes = {}
+        changes: ChangesDict = {}
 
         def by_key(ps):
             ret = {}
@@ -474,6 +498,7 @@ class ControlEditor(object):
         try:
             if self._template_only:
                 os.unlink(self.path)
+                self.changed_files = [self.path]
                 raise FileNotFoundError
             self._primary.__exit__(exc_type, exc_val, exc_tb)
         except GeneratedFile as e:
@@ -481,16 +506,28 @@ class ControlEditor(object):
                 raise
             self.changed = _update_control_template(
                 e.template_path, self.path, self.changes())
+            if self.changed:
+                self.changed_files = [e.template_path, self.path]
+            else:
+                self.changed_files = []
         except FileNotFoundError:
             template_path = _find_template_path(self.path)
             if template_path:
                 self.changed = _update_control_template(
                     template_path, self.path, self.changes(),
                     expand_template=not self._template_only)
+                if self.changed:
+                    self.changed_files = [template_path, self.path]
+                else:
+                    self.changed_files = []
             else:
                 raise
         else:
             self.changed = self._primary.changed
+            if self.changed:
+                self.changed_files = [self.path]
+            else:
+                self.changed_files = []
         return False
 
     def sort_binary_packages(self, keep_first: bool = False) -> None:
@@ -536,7 +573,7 @@ class ControlEditor(object):
         self._primary.paragraphs.remove(para)
 
 
-def parse_relations(text: str):
+def parse_relations(text: str) -> List[Tuple[str, List[PkgRelation], str]]:
     """Parse a package relations string.
 
     (e.g. a Depends, Provides, Build-Depends, etc field)
@@ -631,7 +668,7 @@ def iter_relations(
 
 
 def _iter_relations(relations, package):
-    for i, (head_whitespace, relation, tail_whitespace) in enumerate(
+    for i, (_head_whitespace, relation, _tail_whitespace) in enumerate(
             relations):
         if isinstance(relation, str):  # formatting
             continue
@@ -668,7 +705,7 @@ def ensure_minimum_version(
     changed = False
     relations = parse_relations(relationstr)
     obsolete_relations = []
-    for i, (head_whitespace, relation, tail_whitespace) in enumerate(
+    for i, (_head_whitespace, relation, _tail_whitespace) in enumerate(
             relations):
         if isinstance(relation, str):  # formatting
             continue
@@ -712,7 +749,7 @@ def ensure_exact_version(
     found = False
     changed = False
     relations = parse_relations(relationstr)
-    for (head_whitespace, relation, tail_whitespace) in relations:
+    for (_head_whitespace, relation, _tail_whitespace) in relations:
         if isinstance(relation, str):  # formatting
             continue
         names = [r.name for r in relation]
@@ -754,7 +791,7 @@ def ensure_relation(
     relations = parse_relations(relationstr)
     added = False
     to_remove = []
-    for i, (head_whitespace, relation, tail_whitespace) in enumerate(
+    for i, (_head_whitespace, relation, _tail_whitespace) in enumerate(
             relations):
         if isinstance(relation, str):  # formatting
             continue
@@ -868,7 +905,7 @@ def ensure_some_version(relationstr: str, package: str) -> str:
     if not isinstance(package, str):
         raise TypeError(package)
     relations = parse_relations(relationstr)
-    for (head_whitespace, relation, tail_whitespace) in relations:
+    for (_head_whitespace, relation, _tail_whitespace) in relations:
         if isinstance(relation, str):  # formatting
             continue
         names = [r.name for r in relation]
@@ -930,7 +967,8 @@ def drop_dependency(relationstr: str, package: str) -> str:
     return relationstr
 
 
-def delete_from_list(liststr: str, item_to_delete: str) -> str:
+def delete_from_list(
+        liststr: str, item_to_delete: Union[str, List[str]]) -> str:
     if not item_to_delete:
         raise ValueError(item_to_delete)
     if isinstance(item_to_delete, str):
@@ -1063,6 +1101,8 @@ def suppress_substvar_warnings():
 class PkgRelationFieldEditor(object):
     """Convenience wrapper for editing pkg relation fields."""
 
+    _parsed: Optional[List[Tuple[str, List[PkgRelation], str]]]
+
     def __init__(self, paragraph, name):
         self.paragraph = paragraph
         self.name = name
@@ -1106,6 +1146,8 @@ class PkgRelationFieldEditor(object):
         """
         if isinstance(relation, str):
             relation = parse_relation(relation)
+        if not self._parsed:
+            self._parsed = []
         return _add_relation(self._parsed, relation, position=position)
 
     def iter_relations(self, package):
@@ -1164,3 +1206,10 @@ class PkgRelationFieldEditor(object):
             else:
                 self.paragraph[self.name] = format_relations(self._parsed)
         return False
+
+
+def format_description(summary, long_description):
+    """Format a description based on summary and long description lines.
+    """
+    return summary + "\n" + ''.join(
+        [" %s\n" % line for line in long_description])
