@@ -26,7 +26,7 @@ __all__ = [
 
 from dataclasses import dataclass
 import os
-from typing import Optional, Union
+from typing import Optional, Union, Dict, List
 
 from debian.deb822 import Deb822
 
@@ -42,7 +42,8 @@ from .reformatting import Editor
 
 
 def ensure_minimum_debhelper_version(
-        source: Deb822, minimum_version: Union[str, Version]) -> bool:
+        source: Union[Deb822, Dict[str, str]],
+        minimum_version: Union[str, Version]) -> bool:
     """Ensure that the pakcage is at least using version x of debhelper.
 
     This is a dedicated helper, since debhelper can now also be pulled in
@@ -211,11 +212,16 @@ def parse_maintscript_line(line):
     }.get(args[0], list)(*args[1:])
 
 
+MaintscriptEntry = Union[
+    MaintscriptSupports, MaintscriptRemoveConffile, MaintscriptMoveConffile,
+    MaintscriptSymlinkToDir, MaintscriptDirToSymlink]
+
+
 def serialize_maintscript_line(args):
     return ' '.join(args)
 
 
-class MaintscriptEditor(Editor):
+class MaintscriptEditor(Editor[List[Union[str, MaintscriptEntry]], str]):
 
     def __init__(
             self, path: str = 'debian/maintscript',
@@ -289,7 +295,7 @@ def get_sequences(debian_path='debian', control_editor=None):
     if control_editor is None:
         control_editor = ControlEditor(os.path.join(debian_path, 'control'))
     with control_editor:
-        for ws1, entry, ws2 in parse_relations(
+        for _ws1, entry, _ws2 in parse_relations(
                 control_editor.source.get('Build-Depends', '')):
             for option in entry:
                 if option.name.startswith('dh-sequence-'):
