@@ -93,7 +93,7 @@ def write_quilt_series(entries):
         yield line
 
 
-class QuiltSeriesEditor(Editor):
+class QuiltSeriesEditor(Editor[List[QuiltSeriesEntry], bytes]):
     """Edit a debian/patches/series file."""
 
     def __init__(
@@ -114,7 +114,9 @@ class QuiltSeriesEditor(Editor):
         # TODO(jelmer): Support formatting comments and options
         return b''.join(write_quilt_series(parsed))
 
-    def append(self, name, options=[]):
+    def append(self, name, options=None):
+        if options is None:
+            options = []
         if self._parsed is None:
             self._parsed = []
         self._parsed.append(QuiltSeriesEntry(name, False, options))
